---
title: "Basics"
description: ""
icon: "play"
mode: "wide"
---


```python
from openbrowser import Agent, ChatBrowserUse

agent = Agent(
    task="Search for latest news about AI",
    llm=ChatBrowserUse(),
)

async def main():
    history = await agent.run(max_steps=100)
```

- `task`: The task you want to automate.
- `llm`: Your favorite LLM. See <a href="/customize/supported-models">Supported Models</a>.


The agent is executed using the async `run()` method:

- `max_steps` (default: `100`): Maximum number of steps an agent can take.

Check out all customizable parameters <a href = "/customize/agent/all-parameters"> here</a>. 
